@@ -139,7 +139,6 @@ def get_field_schema_float(field):
     }
 
 
-@get_field_schema.register(models.NullBooleanField)
 @get_field_schema.register(models.BooleanField)
 def get_field_schema_bool(field):
     return {
@@ -147,6 +146,15 @@ def get_field_schema_bool(field):
     }
 
 
+if hasattr(models, "NullBooleanField"):
+
+    @get_field_schema.register(models.NullBooleanField)  # type:ignore
+    def get_field_schema_nullbool(field):
+        return {
+            "kind": FieldKind.BOOLEAN,
+        }
+
+
 @get_field_schema.register(models.DateField)
 def get_field_schema_date(field):
     return {
